=======
Credits
=======

Original Author
---------------

* Krzysztof Dorosz <cypreess@gmail.com>

Development Lead
----------------

* Dominik Kozaczko <dominik@kozaczko.info>

Contributors
------------

Please see https://github.com/django-getpaid/django-getpaid/graphs/contributors

Sponsors
--------

Many thanks to Sunscrapers_ for sponsoring development since version 1.8

.. _Sunscrapers: http://sunscrapers.com/
